@@ -24,6 +24,10 @@ class Context:
   def log(self):
     return self.log_mgr.logger
 
+  @property
+  def store(self):
+    return self.store_as_dict()
+
   def __init__(self, log_mgr, config_mgr):
     self.config_mgr = config_mgr
     self.log_mgr = log_mgr
@@ -112,6 +116,16 @@ class Context:
     """
     self.log.vault.add(secret)
 
+  def store_as_dict(self):
+    parent_store = {}
+    if self.parent is not None:
+      parent_store = self.parent.store_as_dict()
+    store = self._store.as_dict()
+    for key, value in parent_store.items():
+      if key not in store:
+        store[key] = value
+    return store
+
   def _register_instance_secrets(self, instance, args):
     if instance.specification.get("args") is not None and args is not None:
       class_args = instance.specification.get("args")
