@@ -33,3 +33,10 @@ class Context(BaseContext):
 
   def get_method_item(self):
     return None
+
+  def store_as_dict(self):
+    store = super().store_as_dict()
+    store["step_item"] = self.get_step_item()
+    store["action_item"] = self.get_action_item()
+    store["method_item"] = None
+    return store
