@@ -1,4 +1,3 @@
-import logging
 from laboro.logic.processor import Processor
 from laboro.workflow.method import Method
 from laboro.context.method import Context as MethodContext
@@ -38,8 +37,8 @@ class Action:
 
   def __init__(self, context, name, methods,
                instances=None, when=None, loop=None):
-    self.ctx = context
     self.name = name
+    self.ctx = context
     self.when = when
     self.loop = loop
     self.instances = instances
@@ -66,17 +65,16 @@ class Action:
     If the ``runnable`` property evaluate to ``True``, calling the ``run()`` method will instantiate the instance when needed and run all ``methods`` within the instance methods list.
     The methods within instance methods list will be executed for each item in the ``iterable`` property.
     """
+    self.ctx.log.log_section("ACTION", self.name)
     for instance in self.instances:
-
       self._instantiate(instance)
     for item in self.iterable:
       self.ctx.set_action_item(item)
       if self.runnable:
-        self.ctx.log.log_section("ACTION", self.name)
         for action_method in self.methods:
           with Method(MethodContext(parent=self.ctx),
                       **action_method) as method:
             method.run()
       else:
         msg = f"Skipping {self.name}: Condition not met: {self.when}"
-        self.ctx.log.log_section("STEP", msg, level=logging.WARNING)
+        self.ctx.log.warning(msg)
